LinuxTouchEventParser

Struct LinuxTouchEventParser 

pub struct LinuxTouchEventParser { /* private fields */ }
A state machine accepts uapi::input_event, produces fir::InputReport when (Touch Event.. + Sync Event) received.

This parser currently only supports “Type B” protocol in: https://www.kernel.org/doc/Documentation/input/multi-touch-protocol.txt

Each event report contains a sequence of packets (uapi::input_event). EV_EYN means the report is completed.

There may be multiple contacts inside the sequence of packets, each contact data started by a MT_SLOT event with slot_id.

In the initiated contact, slot (X) will include a ABS_MT_TRACKING_ID event. In following events in slot (X) will continue use the same TRACKING_ID. Slot (X) with TRACKING_ID (-1) means the contact is lifted.

Warning output, clean state and return errno when received events:

  • unknown events type / code.
  • “Type A” events: SYN_MT_REPORT.
  • invalid event.
  • not follow “Type B” pattern.

Implementations

Source

impl LinuxTouchEventParser

pub fn create() -> Self

Create the LinuxTouchEventParser.

pub fn handle(&mut self, e: input_event) -> Result<Option<InputReport>, Errno>

Handle received input_event, only produce event when SYN_REPORT is received.